Module sync_loop

Module sync_loop 

Background mesh sync loop.

Spawns a tokio task that periodically syncs all SYNC_TABLES with every active peer in the peers registry.

Functions

spawn_sync_loop
Spawn background tokio task: every interval, sync all tables with all active peers.